pub fn rtc_calib_get_chan_compens(
_unit: AdcCalibUnit,
channel: u8,
atten: Attenuation,
) -> Option<i32>Available on crate feature
unstable only.Expand description
Returns the channel specific calibration compensation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.